Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(100)

Unified Diff: content/browser/frame_host/cross_process_frame_connector.cc

Issue 2023453003: Make RenderFrameHostImpl::GetRenderWidgetHost() always return an object (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressing creis' comments Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/cross_process_frame_connector.cc
diff --git a/content/browser/frame_host/cross_process_frame_connector.cc b/content/browser/frame_host/cross_process_frame_connector.cc
index 6002fcaa6b18e3707e4430c4cdf62f085f4adbc6..5f77f504a9cdeb816a31e7a7979376ea3b03edb1 100644
--- a/content/browser/frame_host/cross_process_frame_connector.cc
+++ b/content/browser/frame_host/cross_process_frame_connector.cc
@@ -277,7 +277,7 @@ void CrossProcessFrameConnector::SetRect(const gfx::Rect& frame_rect) {
if (view_) {
view_->SetBounds(frame_rect);
// Out-of-process iframes nested underneath this one implicitly have their
// view rects changed when their ancestor is repositioned, and therefore
// need to have their screen rects updated.
FrameTreeNode* proxy_node =
@@ -286,8 +286,7 @@ void CrossProcessFrameConnector::SetRect(const gfx::Rect& frame_rect) {
old_rect.y() != child_frame_rect_.y()) {
for (FrameTreeNode* node :
proxy_node->frame_tree()->SubtreeNodes(proxy_node)) {
- if (node != proxy_node &&
- node->current_frame_host()->GetRenderWidgetHost())
+ if (node != proxy_node && node->current_frame_host()->is_local_root())
node->current_frame_host()->GetRenderWidgetHost()->SendScreenRects();
}
}
@@ -277,7 +277,7 @@ void CrossProcessFrameConnector::SetRect(const gfx::Rect& frame_rect) {
if (view_) {
view_->SetBounds(frame_rect);
- // Out-of-process iframes nested underneath this one implicitly have their
+ // Other local root frames nested underneath this one implicitly have their
// view rects changed when their ancestor is repositioned, and therefore
// need to have their screen rects updated.
« no previous file with comments | « content/browser/browser_plugin/browser_plugin_guest.cc ('k') | content/browser/frame_host/render_frame_host_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698